function Get-PstFiles {
<#  
.SYNOPSIS  
   	Lists all PST files and their sizes in MB. Optionally can export data to .csv

.DESCRIPTION  
    

.NOTES  
    Version							: 1.0 - See changelog at 
		Wish list						: Better error trapping
    Rights Required			: Local administrator on server;
    										: ExecutionPolicy of AllSigned, RemoteSigned, or Unrestricted
    Sched Task Required	: No
    Exchange Version	  : N/A
    Author/Copyright		:  Pat Richard, Lync MVP - All Rights Reserved
    Email/Blog/Twitter	: pat@innervation.com 	http://www.ehloworld.com @patrichard
    Dedicated Post			: 
    Disclaimer   				: You running this script means you won't blame me if this breaks your stuff. This script is provided AS IS 
    											without warranty of any kind. I disclaim all implied warranties including, without limitation, any implied 
    											warranties of merchantability or of fitness for a particular purpose. The entire risk arising out of the use 
    											or performance of the sample scripts and documentation remains with you. In no event shall I be liable for 
    											any damages whatsoever (including, without limitation, damages for loss of business profits, business 
    											interruption, loss of business information, or other pecuniary loss) arising out of the use of or inability 
    											to use the script or documentation. 
    Info Stolen from 		: http://social.technet.microsoft.com/Forums/en-US/ITCG/thread/bfe66e89-e6ea-48e8-bcab-6f260493944e

.LINK  
		

.EXAMPLE
    .\Get-PstFiles.ps1 -path c:\pstfiles
    
    Description
		-----------
		Runs script with default values.

.INPUTS
    None. You cannot pipe objects to this script.
#>
#Requires -Version 2.0

  [CmdletBinding(SupportsShouldProcess = $True)]
  param(
		[Parameter(Position = 0, ValueFromPipeline = $True, ValueFromPipelineByPropertyName = $True, Mandatory = $False)]
		[ValidateNotNullOrEmpty()]
		[string]$path,
		[Parameter(Position = 1, ValueFromPipeline = $True, ValueFromPipelineByPropertyName = $True, Mandatory = $False)]
		[ValidateNotNullOrEmpty()]
		[string]$filter = "*.pst",
		[Parameter(Position = 2, ValueFromPipeline = $True, ValueFromPipelineByPropertyName = $True, Mandatory = $False)]
		[ValidatePattern(".csv")]
		[string]$file
  )
  Begin{
      $PSTFiles = @()
  }
  Process{
		Get-ChildItem $path -recurse -Filter $filter | ? {$_.PSIsContainer -eq $False} | % {
			$obj = New-Object PSObject
			$obj | Add-Member NoteProperty Directory $_.DirectoryName
			$obj | Add-Member NoteProperty Name $_.Name
			$obj | Add-Member NoteProperty "Size in MB" ([System.Math]::Round(($_.Length/1mb),2))
			$obj | Add-Member NoteProperty Owner ((Get-ACL $_.FullName).Owner)
			$PSTFiles += $obj
		}
  }
  end{
		if ($file){
			$PSTFiles | Export-CSV "$file" -NoTypeInformation 
		}else{
			$PSTFiles
		}
  }
}